@@ -5,14 +5,14 @@
                            'ShadowFB',
                            {
                              'value_type' => 'boolean',
-                             'built_in' => 1,
+                             'upstream_default' => 1,
                              'type' => 'leaf',
                              'description' => 'Enable or disable use of the shadow framebuffer layer. This option is recommended for performance reasons.'
                            },
                            'ModeSetClearScreen',
                            {
                              'value_type' => 'boolean',
-                             'built_in' => 1,
+                             'upstream_default' => 1,
                              'type' => 'leaf',
                              'description' => 'Enable or disable use of the shadow framebuffer layer. This option is recommended for performance reasons.'
                            }
